Method: Hanami.env?
- Defined in:
- lib/hanami.rb
.env?(*names) ⇒ Boolean
Returns true if env matches any of the given names
188 189 190 |
# File 'lib/hanami.rb', line 188 def self.env?(*names) names.map(&:to_sym).include?(env) end |
Returns true if env matches any of the given names
188 189 190 |
# File 'lib/hanami.rb', line 188 def self.env?(*names) names.map(&:to_sym).include?(env) end |