Method: Hanami::Config::Assets#serve

Defined in:
lib/hanami/config/assets.rb

#serveHanami::Config::Actions::Cookies

Serve static assets.

When this is true, the app will serve static assets.

If not set, this will:

* Check if the `HANAMI_SERVE_ASSETS` environment variable is set to `"true"`.
* If not, it will check if the app is running in the `development` or `test` environment.

Examples:

config.assets.serve = true

Returns:

Since:

  • 2.1.0



36
# File 'lib/hanami/config/assets.rb', line 36

setting :serve