Method: Hanami::Settings#inspect
- Defined in:
- lib/hanami/settings.rb
#inspect ⇒ String
Returns a string containing a human-readable representation of the settings.
This includes setting names only, not any values, to ensure that sensitive values do not inadvertently leak.
Use #inspect_values to inspect settings with their values.
196 197 198 |
# File 'lib/hanami/settings.rb', line 196 def inspect "#<#{self.class} [#{config._settings.map(&:name).join(", ")}]>" end |