Method: Hanami::Slice::ClassMethods#keys

Defined in:
lib/hanami/slice.rb

#keysArray<String>

Returns an array of keys for all currently registered components in the container.

For a prepared slice, this will be the set of components that have been previously resolved. For a booted slice, this will be all components available for the slice.

Returns:

  • (Array<String>)

Since:

  • 2.0.0



616
617
618
# File 'lib/hanami/slice.rb', line 616

def keys
  container.keys
end