Module: Hanami::Extensions::View::Part::ClassMethods Private
- Defined in:
- lib/hanami/extensions/view/part.rb
Overview
This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.
Instance Method Summary collapse
Instance Method Details
#configure_for_slice(slice) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
26 27 28 29 30 31 32 33 34 |
# File 'lib/hanami/extensions/view/part.rb', line 26 def configure_for_slice(slice) extend SliceConfiguredPart.new(slice) const_set :PartHelpers, Class.new(PartHelpers) { |klass| # Call configure_for_slice explicitly, since this is an anonymous class at this point, # so the slice cannot be inferred from its name. klass.configure_for_slice(slice) } end |