Class: Hanami::Providers::Logger Private

Inherits:
Hanami::Provider::Source show all
Defined in:
lib/hanami/providers/logger.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Provider source to register logger component in Hanami slices.

See Also:

Since:

  • 2.0.0

Instance Attribute Summary

Attributes inherited from Hanami::Provider::Source

#slice

Instance Method Summary collapse

Methods inherited from Hanami::Provider::Source

#initialize, #target_container

Constructor Details

This class inherits a constructor from Hanami::Provider::Source

Instance Method Details

#loggerDry::Logger::Dispatcher

Returns the logger instance that will be registered as the slice's "logger" component.

This is memoized, so lifecycle callbacks added when extending the provider via Slice::ClassMethods#configure_provider (such as a before :start or after :start hook) can access and customize the very same logger that start registers — for example, to add a logging backend.

Returns:

  • (Dry::Logger::Dispatcher)

    the default logger, or the logger instance configured via Config#logger=

Since:

  • 3.0.0



30
31
32
# File 'lib/hanami/providers/logger.rb', line 30

def logger
  @logger ||= Hanami.app.config.logger_instance
end

#startObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Since:

  • 2.0.0



14
15
16
# File 'lib/hanami/providers/logger.rb', line 14

def start
  register :logger, logger
end