Method: Hanami.logger
- Defined in:
- lib/hanami.rb
.logger ⇒ Dry::Logger::Dispatcher
Returns the app’s logger.
Direct global access to the logger via this method is not recommended. Instead, consider accessing the logger via the app or slice container, in most cases as an dependency using the Deps mixin.
215 216 217 |
# File 'lib/hanami.rb', line 215 def self.logger app[:logger] end |