Method: Hanami::Config::Assets#serve
- Defined in:
- lib/hanami/config/assets.rb
#serve ⇒ Hanami::Config::Actions::Cookies
Serve static assets.
When this is true, the app will serve static assets.
If not set, this will:
* Check if the `HANAMI_SERVE_ASSETS` environment variable is set to `"true"`.
* If not, it will check if the app is running in the `development` or `test` environment.
36 |
# File 'lib/hanami/config/assets.rb', line 36 setting :serve |