Method: Hanami::Config#shared_app_component_keys
- Defined in:
- lib/hanami/config.rb
#shared_app_component_keys ⇒ Array<String>
Sets the keys for the components to be imported from the app into all other slices.
You should append items to this array, since the default shared components are essential for slices to operate within the app.
96 97 98 99 100 101 102 103 |
# File 'lib/hanami/config.rb', line 96 setting :shared_app_component_keys, default: %w[ inflector logger notifications rack.monitor routes settings ] |