Returns true if the component with the given key is registered in the container.
For a prepared slice, calling key? will also try to load the component if not loaded already.
key?
Parameters:
the component key
Returns:
Since:
2.0.0
596 597 598
# File 'lib/hanami/slice.rb', line 596 def key?(...) container.key?(...) end